@@ -1,4 +1,4 @@
-/* $Id: chars.c,v 1.122.2.1 2007/04/19 03:15:04 dolorous Exp $ */
+/* $Id: chars.c,v 1.122.2.2 2007/04/23 14:03:28 dolorous Exp $ */
 /**************************************************************************
  *   chars.c                                                              *
  *                                                                        *
@@ -983,9 +983,7 @@ bool has_blank_mbchars(const char *s)
 	bool retval = FALSE;
 
 	while (*s != '\0') {
-	    int chr_mb_len;
-
-	    chr_mb_len = parse_mbchar(s, chr_mb, NULL);
+	    int chr_mb_len = parse_mbchar(s, chr_mb, NULL);
 
 	    if (is_blank_mbchar(chr_mb)) {
 		retval = TRUE;
