@@ -1,9 +1,9 @@
-/* $Id: proto.h,v 1.369 2006/11/27 05:09:16 dolorous Exp $ */
+/* $Id: proto.h,v 1.372 2007/01/11 21:36:29 dolorous Exp $ */
 /**************************************************************************
  *   proto.h                                                              *
  *                                                                        *
  *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 Chris Allegretta    *
- *   Copyright (C) 2005, 2006 David Lawrence Ramsey                       *
+ *   Copyright (C) 2005, 2006, 2007 David Lawrence Ramsey                 *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 2, or (at your option)  *
@@ -26,8 +26,7 @@
 
 #include "nano.h"
 
-/* All public external variables.  See global.c for their
- * descriptions. */
+/* All external variables.  See global.c for their descriptions. */
 #ifndef NANO_TINY
 extern sigjmp_buf jump_buf;
 extern bool jump_buf_main;
@@ -142,7 +141,7 @@ extern int reverse_attr;
 
 extern char *homedir;
 
-/* All public functions in browser.c. */
+/* All functions in browser.c. */
 #ifndef DISABLE_BROWSER
 char *do_browser(char *path, DIR *dir);
 char *do_browse_from(const char *inpath);
@@ -161,7 +160,7 @@ void do_last_file(void);
 char *striponedir(const char *path);
 #endif
 
-/* All public functions in chars.c. */
+/* All functions in chars.c. */
 #ifdef ENABLE_UTF8
 void utf8_init(void);
 bool using_utf8(void);
@@ -243,14 +242,14 @@ bool is_valid_unicode(wchar_t wc);
 bool is_valid_mbstring(const char *s);
 #endif
 
-/* All public functions in color.c. */
+/* All functions in color.c. */
 #ifdef ENABLE_COLOR
 void set_colorpairs(void);
 void color_init(void);
 void color_update(void);
 #endif
 
-/* All public functions in cut.c. */
+/* All functions in cut.c. */
 void cutbuffer_reset(void);
 void cut_line(void);
 #ifndef NANO_TINY
@@ -272,7 +271,7 @@ void do_cut_till_end(void);
 #endif
 void do_uncut_text(void);
 
-/* All public functions in files.c. */
+/* All functions in files.c. */
 void make_new_buffer(void);
 void initialize_buffer(void);
 void initialize_buffer_text(void);
@@ -311,13 +310,13 @@ bool check_operating_dir(const char *currpath, bool allow_tabcomp);
 void init_backup_dir(void);
 #endif
 int copy_file(FILE *inn, FILE *out);
-int write_file(const char *name, FILE *f_open, bool tmp, append_type
+bool write_file(const char *name, FILE *f_open, bool tmp, append_type
 	append, bool nonamechange);
 #ifndef NANO_TINY
-int write_marked_file(const char *name, FILE *f_open, bool tmp,
+bool write_marked_file(const char *name, FILE *f_open, bool tmp,
 	append_type append);
 #endif
-int do_writeout(bool exiting);
+bool do_writeout(bool exiting);
 void do_writeout_void(void);
 char *real_dir_from_tilde(const char *buf);
 #if !defined(DISABLE_TABCOMP) || !defined(DISABLE_BROWSER)
@@ -325,6 +324,7 @@ int diralphasort(const void *va, const void *vb);
 void free_chararray(char **array, size_t len);
 #endif
 #ifndef DISABLE_TABCOMP
+bool is_dir(const char *buf);
 char **username_tab_completion(const char *buf, size_t *num_matches,
 	size_t buflen);
 char **cwd_tab_completion(const char *buf, bool allow_files, size_t
@@ -340,7 +340,7 @@ bool writehist(FILE *hist, filestruct *histhead);
 void save_history(void);
 #endif
 
-/* All public functions in global.c. */
+/* All functions in global.c. */
 size_t length_of_list(const shortcut *s);
 #ifndef NANO_TINY
 void toggle_init_one(int val
@@ -362,7 +362,7 @@ void free_shortcutage(shortcut **shortcutage);
 void thanks_for_all_the_fish(void);
 #endif
 
-/* All public functions in help.c. */
+/* All functions in help.c. */
 #ifndef DISABLE_HELP
 void do_help(void (*refresh_func)(void));
 void do_help_void(void);
@@ -374,7 +374,7 @@ void parse_help_input(int *kbinput, bool *meta_key, bool *func_key);
 size_t help_line_len(const char *ptr);
 #endif
 
-/* All public functions in move.c. */
+/* All functions in move.c. */
 void do_first_line(void);
 void do_last_line(void);
 void do_page_up(void);
@@ -418,7 +418,7 @@ void do_scroll_down(void);
 void do_left(void);
 void do_right(void);
 
-/* All public functions in nano.c. */
+/* All functions in nano.c. */
 filestruct *make_new_node(filestruct *prevnode);
 filestruct *copy_node(const filestruct *src);
 void splice_node(filestruct *begin, filestruct *newnode, filestruct
@@ -489,7 +489,7 @@ bool do_mouse(void);
 #endif
 void do_output(char *output, size_t output_len, bool allow_cntrls);
 
-/* All public functions in prompt.c. */
+/* All functions in prompt.c. */
 int do_statusbar_input(bool *meta_key, bool *func_key, bool *s_or_t,
 	bool *ran_func, bool *finished, bool allow_funcs, void
 	(*refresh_func)(void));
@@ -546,7 +546,7 @@ int do_prompt(bool allow_tabs,
 void do_prompt_abort(void);
 int do_yesno_prompt(bool all, const char *msg);
 
-/* All public functions in rcfile.c. */
+/* All functions in rcfile.c. */
 #ifdef ENABLE_NANORC
 void rcfile_error(const char *msg, ...);
 char *parse_next_word(char *ptr);
@@ -567,9 +567,9 @@ void parse_rcfile(FILE *rcstream
 void do_rcfile(void);
 #endif
 
-/* All public functions in search.c. */
+/* All functions in search.c. */
 #ifdef HAVE_REGEX_H
-int regexp_init(const char *regexp);
+bool regexp_init(const char *regexp);
 void regexp_cleanup(void);
 #endif
 void not_found_msg(const char *str);
@@ -623,7 +623,7 @@ char *get_history_completion(filestruct **h, const char *s, size_t len);
 #endif
 #endif
 
-/* All public functions in text.c. */
+/* All functions in text.c. */
 #ifndef NANO_TINY
 void do_mark(void);
 #endif
@@ -680,7 +680,7 @@ void do_wordlinechar_count(void);
 #endif
 void do_verbatim_input(void);
 
-/* All public functions in utils.c. */
+/* All functions in utils.c. */
 int digits(size_t n);
 void get_homedir(void);
 bool parse_num(const char *str, ssize_t *val);
@@ -728,7 +728,7 @@ void dump_filestruct(const filestruct *inptr);
 void dump_filestruct_reverse(void);
 #endif
 
-/* All public functions in winio.c. */
+/* All functions in winio.c. */
 void get_key_buffer(WINDOW *win);
 size_t get_key_buffer_len(void);
 void unget_input(int *input, size_t input_len);
